
<!-- index_extra.inc -->
<br>
<br>

<center>

<table width=210 bgcolor=<%=$DarkRowColor%> border=1 cellpadding=3 cellspacing=0>
<tr><td align=center><b><font size=-1 color=white face=verdana,helvetica,arial><nobr>WEB SITE PREMIERS</nobr></font></b></td></tr>
<tr><td>

  <table bgcolor=white width=100% cellpadding=4 cellspacing=0 border=0>
    <tr><td>

<center>
  <a href="http://www.mfm.com"><img src=communication_software.gif alt="Communication Software Inc." border=0></a>
<p>
<a href=http://www.huff.com/>HUFF Realty</a>
<br>
<a href=http://www.starone.com/>Star One Realtors</a>
<br>
<a href=http://www.comey.com/>Comey & Shepherd Realtors</a>
<br>
<a href=http://www.unlimitedrealestate.net/>RE/MAX Unlimited Realtors</a>
<br>
<a href=http://www.cincinnatibuilders.com/>Cincinnati Builders</a>
<br>
<a href=http://www.airportdays.com/>Blue Ash Airport Days Airshow</a>
</center>

<p>

Working in a team environment where you have HTML coders and perl
coders, Apache::ASP makes it easy for the HTML folks to change the look
of the page without knowing perl. Using Apache::ASP (instead of another
embedded perl solution) allows the HTML jockeys to use a variety of HTML
tools that understand ASP, which reduces the amount of code they break
when editing the HTML.  Using Apache::ASP instead of M$ ASP allows us to
use perl (far superior to VBScript) and Apache (far superior to IIS).
<p>
We've been very pleased with Apache::ASP and its support.

    </td></tr>
  </table>

</td></tr>
</table>

</center>
